@@ -220,7 +220,7 @@ class DocumentClient(BaseDocumentCloudClient):
         if project: params['project'] = project
         # Make the request
         response = self._make_request(self.BASE_URI + 'upload.json', params, MultipartPostHandler)
-        return json.loads(response)['id']
+        return self.get(json.loads(response)['id'])
     
     @credentials_required
     def delete(self, id):
@@ -263,20 +263,49 @@ class ProjectClient(BaseDocumentCloudClient):
             obj_list.append(proj)
         return obj_list
     
-    def get(self, id):
+    def get(self, id=None, title=None):
         """
-        Retrieve a particular project using its unique identifier.
+        Retrieve a particular project using its unique identifier or it's title.
+        
+        But not both.
         
         Example usage:
         
             >> documentcloud.projects.get(u'arizona-shootings')
         
         """
+        # Make sure the kwargs are kosher
+        if id and title:
+            raise ValueError("You can only retrieve a Project by id or title, not by both")
+        elif not id and not title:
+            raise ValueError("You must provide an id or a title to make a request.")
+        # Pull the hits
+        if id:
+            hit_list = [i for i in self.all() if str(i.id) == str(id)]
+        elif title:
+            hit_list = [i for i in self.all() if i.title.lower().strip() == title.lower().strip()]
+        # Throw an error if there's more than one hit.
+        if len(hit_list) > 1:
+            raise DuplicateObjectError("There is more than one project that matches your request.")
+        # Try to pull the first hit
         try:
-            return [i for i in self.all() if str(i.id) == str(id)][0]
+            return hit_list[0]
         except IndexError:
+            # If it's not there, you know to throw this error.
             raise DoesNotExistError("The resource you've requested does not exist or is unavailable without the proper credentials.")
     
+    def get_by_id(self, id):
+        """
+         A reader-friendly shortcut to retrieve projects based on their ID. 
+        """
+        return self.get(id=id)
+    
+    def get_by_title(self, title):
+        """
+        A reader-friendly shortcut to retrieve projects based on their title. 
+        """
+        return self.get(title=title)
+    
     @credentials_required
     def create(self, title, description=None, document_ids=None):
         """
@@ -304,7 +333,24 @@ class ProjectClient(BaseDocumentCloudClient):
         # If it doesn't exist, that suggests the project already exists
         if not new_id:
             raise DuplicateObjectError("The Project title you tried to create already exists")
-        return new_id
+        # Fetch the actual project object from the API and return that.
+        return self.get(new_id)
+    
+    @credentials_required
+    def get_or_create_by_title(self, title):
+        """
+        Fetch a title, if it exists. Create it if it doesn't.
+        
+        Returns a tuple with the object first, and then a boolean that indicates
+        whether or not the object was created fresh. True means it's brand new.
+        """
+        try:
+            obj = self.get_by_title(title)
+            created = False
+        except DoesNotExistError:
+            obj = self.create(title=title)
+            created = True
+        return obj, created
     
     @credentials_required
     def delete(self, id):
@@ -747,9 +793,7 @@ class Mention(BaseAPIObject):
     A mention of a search found in the document.
     """
     def __unicode__(self):
-        return unicode("%s: %s" % (self.page, self.text[:50]))
-
-
+        return unicode("Page %s" % (self.page))
 
 
 class Project(BaseAPIObject):
@@ -859,5 +903,3 @@ class Section(BaseAPIObject):
     pass
 
 
-
-
